@@ -8,22 +8,24 @@ sub Box {
 
 	my $self = { $x => shift, $y => shift, $w => shift, $h => shift };
 
-	return bless $self, $class;
+	return bless $self, ref($class) || $class;
 }
 
 sub is_collision {
 	my ($self, $box) = shift;
 
-	if ($box->{x} < $self->{x})
+	if ($box->{x} < $self->{x}) {
 		return 0;
-	if ($box->{x} + $box->{w} > $self->{x} + $self->{w})
+	}
+	if ($box->{x} + $box->{w} > $self->{x} + $self->{w}) {
 		return 0;
-	
-	if ($box->{y} < $self->{y})
+	}	
+	if ($box->{y} < $self->{y}) {
 		return 0;
-	if ($box->{y} + $box->{h} > $self->{y} + $self->{h})
+	}
+	if ($box->{y} + $box->{h} > $self->{y} + $self->{h}) {
 		return 0;
-
+	}
 	return 1;
 }
 	
