@@ -13,7 +13,7 @@ sub Enemy {
 	$self = $self->SUPER::Sprite(shift,shift,shift,shift);
 
 	### fill it with subclass
-	my $self->{$box => Box->new{$x,$y,$w,$h}};
+	my $self->{box} = Box->Box($x,$y,$w,$h);
 	my $self->{$imagelibrary => ImageLibrary->new};
 	my $self->{$app} = shift;
 
