@@ -10,7 +10,7 @@ sub Exit {
 	my $self = {};
 	bless $self, $class;
 
-	$self = $self->SUPER::Box{shift,shift,shift,shift};
+	$self = $self->SUPER::Box(shift,shift,shift,shift);
 
 	return bless $self, $class;
 }
