@@ -7,9 +7,7 @@ our @ISA = "HollyGame::Player";
 
 sub PlayerExample {
 	my $class = shift;
-	my $self = {};
-	bless $self, $class;
-	my $self = $self->SUPER::Player;
+	my $self = $class->SUPER::Player;
 	$self->$app = shift;
 
 	my $image1 = new SDL::Surface(-name=>"./images/player.jpg");
@@ -19,7 +17,7 @@ sub PlayerExample {
 	my $image3 = new SDL::Surface(-name=>"./images/player3.jpg");
 	$self->{imagelibrary}->push{$image1};
 
-	return $self;	
+	return bless $self, ref($class) || $class;	
 }
 
 sub update {
