@@ -7,9 +7,7 @@ our @ISA = "HollyGame::Sprite";
 
 sub SpriteExample {
 	my $class = shift;
-	my $self = {};
-	bless $self, $class;
-	my $self = $self->SUPER::Sprite(shift,shift,shift,shift);
+	my $self = $class->SUPER::Sprite(shift,shift,shift,shift);
 	$self->$app = shift;
 
 	my $image1 = new SDL::Surface(-name=>"./images/larrysprite1.jpg");
@@ -20,7 +18,7 @@ sub SpriteExample {
 	$self->{imagelibrary}->push{$image1};
 	$self->{screenrect} = new SDL::Rect -width => $self->{box}->{w}, -height => $self->{box}->{h};
 
-	return $self;	
+	return bless $self, ref($class) || $class;	
 }
 
 sub update {
